@@ -23,8 +23,6 @@ package MooX::Attributes::Shadow::Role;
 
 use strict;
 
-our $VERSION = '0.01_06';
-
 use Moo::Role;
 
 use MooX::Attributes::Shadow ':all';
@@ -33,12 +31,12 @@ use MooX::Attributes::Shadow ':all';
 sub shadowable_attrs (@) {
 
     my $attrs = [ @_ ];
+    my $from = caller;
 
     ## no critic (ProhibitNoStrict)
     no strict 'refs';
-    no warnings 'redefine';
 
-    *{ caller() . '::shadowable_attrs' } = sub (@) { @{$attrs} };
+    *{ caller . '::_shadowable_attrs'} = sub { @{$attrs} };
 
     return;
 }
@@ -77,13 +75,13 @@ MooX::Attributes::Shadow::Role - enumerate shadowable attributes in a contained
   # specify which ones
   Foo->shadow_attrs( fmt => sub { 'pfx_' . shift } );
 
-  # create an attribute which holds the contained oject, and
-  # delegate the shadowed accessors to it.
-  has foo   => ( is => 'ro',
-                 lazy => 1,
-                 default => sub { Foo->new( Foo->xtract_attrs(  shift ) ) },
-                 handles => Foo->shadowed_attrs,
-               );
+  # later in the code, use the attributes when creating a new Foo
+  # object.
+
+  sub create_foo {
+    my $self = shift;
+    my $foo = Foo->new( Foo->xtract_attrs( $self ) );
+  }
 
 
 =head1 DESCRIPTION
@@ -110,13 +108,6 @@ This is called by the contained class to identify which attributes are
 available for shadowing.  It does B<not> create them, it merely
 records them.
 
-Subsequent calls will return the names of the attributes which may be
-shadowed as an array:
-
-   Class->shadowable_attrs( qw[ a b c ] );
-   @attrs = Class->shadowable_attrs;
-
-
 =back
 
 
@@ -128,8 +119,10 @@ shadowed as an array:
 
    ContainedClass->shadow_attrs( %options );
 
-This method creates read-only attributes shadowing the
-I<ContainedClass>'s shadowable attributes in the class which calls it.
+This method creates attributes shadowing the I<ContainedClass>'s
+shadowable attributes in the class which calls it.  The attributes are
+created as read-only.  There is no means of specifying additional
+attribute options.
 
 It takes the following options:
 
@@ -139,69 +132,21 @@ It takes the following options:
 
 This is a reference to a subroutine which should return a modified
 attribute name (e.g. to prevent attribute collisions).  It is passed
-the attribute name as its first parameter.
+the attribute name as its first parameters.
 
-=item instance
+=item attrs
 
-In the case where more than one instance of an object is contained,
-this (string) is used to identify an individual instance.
-
-=item private
-
-If true, the actual attribute name is mangled; the attribute
-initialization name is left untouched (see the C<init_arg> option to
-the B<Moo> C<has> subroutine).  This defaults to true.
+This is a list of attributes to shadow; this overrides the list
+provided by the contained class in the call to B<shadowable_attrs>.
 
 =back
 
-=item B<shadowed_attrs>
-
-  $attrs = ContainedClass->( [$container,] \%options );
-
-Return a hash of attributes shadowed into C<$container>.  If
-C<$container> is provided it may be either a class name or an
-object. If it is not provided, the package name of the calling routine
-is used.
-
-It takes the following options:
-
-=over
-
-=item instance
-
-In the case where more than one instance of an object is contained,
-this (string) is used to identify an individual instance.
-
-=back
-
-The keys in the returned hash are the attribute initialization names
-(not the mangled ones) in the I<container> class; the hash values are
-the attribute names in the I<contained> class.  This makes it easy to
-delegate accessors to the contained class:
-
-  has foo   => ( is => 'ro',
-                 lazy => 1,
-                 default => sub { Foo->new( Foo->xtract_attrs( shift ) ) },
-                 handles => Foo->shadowed_attrs,
-               );
-
 =item B<xtract_attrs>
 
-  %attrs = ContainedClass->xtract_attrs( $container_obj, \%options );
+  %shadowed_attrs = ContainedClass->xtract_attrs( $obj );
 
-After the container class is instantiated, B<xtract_attrs> is used to
-extract attributes for the contained object from the container object.
-
-It takes the following options:
-
-=over
-
-=item instance
-
-In the case where more than one instance of an object is contained,
-this (string) is used to identify an individual instance.
-
-=back
+This is extracts the shadowed attributes from an object instantiated
+from the containing class.
 
 =back
 
